@@ -1,5 +1,5 @@
 <?php
-/* $Id: dutch-utf-8.inc.php 10110 2007-03-15 21:11:38Z lem9 $ */
+/* $Id: dutch-utf-8.inc.php 10468 2007-06-27 21:01:13Z lem9 $ */
 
 /*
  * Updated by "CaliMonk" <calimonk at gmx.net> on 2005/01/04.
@@ -62,7 +62,6 @@ $strAscending = 'Oplopend';
 $strAtBeginningOfTable = 'Aan het begin van de tabel';
 $strAtEndOfTable = 'Aan het eind van de tabel';
 $strAttr = 'Attributen';
-$strAutodetect = 'Auto detectie';
 $strAutomaticLayout = 'Automatische lay-out';
 
 $strBack = 'Terug';
@@ -92,7 +91,7 @@ $strBzip = '"ge-bzipt"';
 
 $strCalendar = 'Kalender';
 $strCannotLogin = 'Kan niet inloggen op de MySQL server';
-$strCantLoad = 'Kan de %s extentie niet laden,<br />Controleer de PHP Configuratie';
+$strCantLoad = 'Kan de [a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a]-extensie niet laden. Controleer de PHP configuratie.';
 $strCantLoadRecodeIconv = 'Kan iconv of recode extensies niet laden die nodig zijn voor de Karakterset conversie, configureer php om deze extensies toe te laten of schakel Karakterset conversie uit in phpMyAdmin';
 $strCantRenameIdxToPrimary = 'Kan index niet naar PRIMARY hernoemen';
 $strCantUseRecodeIconv = 'Kan iconv, libiconv en recode_string functies niet gebruiken zolang de extensies geladen moeten worden. Controleer de php configuratie.';
@@ -151,7 +150,6 @@ $strCreatePdfFeat = 'Aanmaken van PDF bestanden';
 $strCreationDates = 'Creatie/Update/Controleer datum';
 $strCriteria = 'Criteria';
 $strCroatian = 'Kroatisch';
-$strCSVOptions = 'CSV opties';
 $strCyrillic = 'Cyrillisch';
 $strCzechSlovak = 'Tsjechische-Slowaak';
 $strCzech = 'Tsjechisch';
@@ -161,7 +159,6 @@ $strDatabase = 'Database';
 $strDatabaseEmpty = 'De database naam is leeg!';
 $strDatabaseExportOptions = 'Database export opties';
 $strDatabaseHasBeenDropped = 'Database %s is vervallen.';
-$strDatabaseNoTable = 'Deze database bevat geen tabel!';
 $strDatabases = 'databases';
 $strDatabasesDropped = '%s databases zijn succesvol verwijderd.';
 $strDatabasesStats = 'Database statistieken';
@@ -223,7 +220,6 @@ $strError = 'Fout';
 $strEscapeWildcards = 'Wildcards _ en % moeten worden ge-escaped met een \ om ze letterlijk te gebruiken';
 $strEstonian = 'Estlands';
 $strExcelEdition = 'Excel editie';
-$strExcelOptions = 'Excel opties';
 $strExecuteBookmarked = 'Voor de gebookmarkte query uit';
 $strExplain = 'Verklaar SQL';
 $strExport = 'Exporteer';
@@ -232,7 +228,6 @@ $strExtra = 'Extra';
 
 $strFailedAttempts = 'Mislukte pogingen';
 $strFieldHasBeenDropped = 'Veld %s is vervallen';
-$strFieldsEmpty = ' Het velden aantal is leeg! ';
 $strFieldsEnclosedBy = 'Velden ingesloten door';
 $strFieldsEscapedBy = 'Velden ontsnapt door';
 $strFieldsTerminatedBy = 'Velden beëindigd door';
@@ -267,7 +262,6 @@ $strHasBeenAltered = 'is veranderd.';
 $strHasBeenCreated = 'is aangemaakt.';
 $strHaveToShow = 'Er moet ten minste 1 weer te geven kolom worden gekozen';
 $strHebrew = 'Hebreeuws';
-$strHexForBinary = 'Gebruik hexadecimale voor binaire velden';
 $strHome = 'Home';
 $strHomepageOfficial = 'Officiële phpMyAdmin Website';
 $strHostEmpty = 'De host naam is leeg!';
@@ -285,10 +279,7 @@ $strIndexHasBeenDropped = 'Index %s is vervallen';
 $strIndex = 'Index';
 $strIndexName = 'Index naam&nbsp;:';
 $strIndexType = 'Index type&nbsp;:';
-$strIndexWarningMultiple = 'Meer dan 1 %s sleutel was gecreëerd voor de kolom `%s`';
-$strIndexWarningPrimary = 'PRIMARY en INDEX sleutels behoren niet beide ingesteld te zijn voor de kolom `%s`';
 $strIndexWarningTable = 'Problemen met de index(en) van de tabel `%s`';
-$strIndexWarningUnique = 'UNIQUE en INDEX sleutels behoren niet beide ingesteld te zijn voor de kolom `%s`';
 $strInnodbStat = 'InnoDB Status';
 $strInsecureMySQL = 'Uw configuratie bestand bevat instellingen (root zonder wachtwoord) die betrekking hebben tot de standaard MySQL account. Uw MySQL server draait met deze standaard waardes, en is open voor ongewilde toegang, het wordt dus aangeraden dit op te lossen.';
 $strInsertAsNewRow = 'Voeg toe als nieuwe rij';
@@ -317,7 +308,6 @@ $strLatexContinued = '(vervolgd)';
 $strLatexIncludeCaption = 'Voeg tabel titel toe';
 $strLatexLabel = 'Label sleutel';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX opties';
 $strLatexStructure = 'Structuur van de tabel __TABLE__';
 $strLatvian = 'Lets';
 $strLengthSet = 'Lengte/Waardes*';
@@ -577,7 +567,6 @@ $strSpaceUsage = 'Ruimte gebruik';
 $strSpanish = 'Spaans';
 $strSplitWordsWithSpace = 'Woorden worden gesplit door een spatie karakter (" ").';
 $strSQLExportType = 'Export type';
-$strSQLOptions = 'SQL opties';
 $strSQLParserBugMessage = 'Er is een kans dat u een fout heeft aangetroffen in de SQL parser. Let er goed op, dat de query op de correcte plaatsen quotes heeft. Een ander mogelijkheid voor deze foutmelding kan zijn dat u het ge-quote text gedeelte in binairy mode heeft. U kunt ook uw query proberen in de command line van MySQL. De MySQL server foutmelding hieronder, mocht die aanwezig zijn, kan ook helpen met het opsporen van fouten. Blijft u problemen houden of als de parser fouten geeft terwijl het goed gaat in de command line van MySQL, probeer dan de SQL query in te korten en een bug report met het stukje data te sturen van het CUT gedeelte hieronder:';
 $strSQLParserUserError = 'Er schijnt een fout te zijn in uw SQL query. Mocht de MySQL server een error hebben terug gegeven, probeer dan of uw hiermee uw fout kunt oplossen.';
 $strSQLQuery = 'SQL-query';
@@ -717,7 +706,6 @@ $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"'
 $strCopy = 'Copy';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
@@ -745,9 +733,7 @@ $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
@@ -778,11 +764,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -810,7 +794,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
@@ -906,7 +889,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -945,7 +928,6 @@ $strSkipQueries = 'Number of records(queries) to skip from start';  //to transla
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -980,16 +962,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
 $strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1005,7 +983,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1050,4 +1027,26 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
 ?>
