@@ -1,9 +1,9 @@
 <?php
-/* $Id: french-iso-8859-15.inc.php 10018 2007-02-26 17:26:53Z lem9 $ */
+/* $Id: french-iso-8859-15.inc.php 10490 2007-07-16 13:08:28Z lem9 $ */
 
 $charset = 'iso-8859-15';
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('o', 'Kio', 'Mio', 'Gio', 'Tio', 'Pio', 'Eio');
@@ -21,7 +21,7 @@ $timespanfmt = '%s jours, %s heures, %s minutes et %s secondes';
 $strAbortedClients = 'Arrts prmaturs';
 $strAccessDenied = 'Accs refus';
 $strAccessDeniedCreateConfig = 'La raison probable est que vous n\'avez pas cr de fichier de configuration. Vous pouvez utiliser le %1$sscript de configuration%2$s dans ce but.';
-$strAccessDeniedExplanation = 'phpMyAdmin a tent de se connecter au serveur MySQL, et le serveur a rejet la connexion. Veuillez vrifier les valeurs de "host", "username" et "password" dans config.inc.php et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
+$strAccessDeniedExplanation = 'phpMyAdmin a tent de se connecter au serveur MySQL, et le serveur a rejet la connexion. Veuillez vrifier les valeurs de "host", "username" et "password" dans votre configuration et vous assurer qu\'elles correspondent aux informations fournies par l\'administrateur du serveur MySQL.';
 $strAction = 'Action';
 $strAddAutoIncrement = 'Inclure la valeur courante de l\'AUTO_INCREMENT';
 $strAddClause = 'Ajouter %s';
@@ -65,7 +65,6 @@ $strAscending = 'Croissant';
 $strAtBeginningOfTable = 'En dbut de table';
 $strAtEndOfTable = 'En fin de table';
 $strAttr = 'Attributs';
-$strAutodetect = 'Dtection automatique';
 $strAutomaticLayout = 'Mise en page automatique';
 
 $strBack = 'Retour';
@@ -154,6 +153,7 @@ $strConnectionError = 'Connexion impossible: rglages incorrects.';
 $strConnections = 'Connexions';
 $strConstraintsForDumped = 'Contraintes pour les tables exportes';
 $strConstraintsForTable = 'Contraintes pour la table';
+$strControluserFailed = 'La connexion au "controluser" tel que dfini dans votre configuration a chou.';
 $strCookiesRequired = 'Vous devez accepter les cookies pour poursuivre.';
 $strCopy = 'Copier';
 $strCopyDatabaseOK = 'La base de donnes %s a t copie sur %s';
@@ -179,8 +179,6 @@ $strCreationDates = 'Dates de cration/modification/vrification';
 $strCriteria = 'Critre';
 $strCroatian = 'croate';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Options CSV';
-$strCSVOptions = 'Options CSV';
 $strCyrillic = 'cyrillique';
 $strCzechSlovak = 'tchque-slovaque';
 $strCzech = 'tchque';
@@ -190,7 +188,6 @@ $strDatabase = 'Base de donnes';
 $strDatabaseEmpty = 'Le nom de la base de donnes est vide!';
 $strDatabaseExportOptions = 'Options d\'exportation';
 $strDatabaseHasBeenDropped = 'La base de donnes %s a t efface.';
-$strDatabaseNoTable = 'Cette base de donnes ne contient aucune table!';
 $strDatabases = 'Bases de donnes';
 $strDatabasesDropped = '%s bases de donnes ont t supprimes.';
 $strDatabasesStatsDisable = 'Dsactiver les statistiques';
@@ -236,7 +233,6 @@ $strDisplayOrder = 'Ordre d\'affichage :';
 $strDisplayPDF = '<b>Afficher le schma</b> en PDF';
 $strDoAQuery = 'Recherche par valeur (passepartout: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'Options DocSQL';
 $strDocu = 'Documentation';
 $strDoYouReally = 'Voulez-vous vraiment effectuer ';
 $strDropDatabaseStrongWarning = 'Vous tes sur le point de DTRUIRE une base de donnes!';
@@ -273,8 +269,8 @@ $strErrorSaveTable = 'Erreur lors de la sauvegarde des coordonnes Concepteur.';
 $strEscapeWildcards = 'Prfixer avec \ les passepartouts _ et % pour un usage littral';
 $strEsperanto = 'Espranto';
 $strEstonian = 'estonien';
+$strEvent = 'vnement';
 $strExcelEdition = 'Excel en version';
-$strExcelOptions = 'Options Excel';
 $strExecuteBookmarked = 'Excuter la requte en signets';
 $strExplain = 'Expliquer SQL';
 $strExport = 'Exporter';
@@ -286,8 +282,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Tentatives choues';
 $strField = 'Champ';
 $strFieldHasBeenDropped = 'Le champ %s a t effac';
+$strFieldInsertFromFileTempDirNotExists = 'Erreur lors du dplacement du fichier tlcharg, voir FAQ 1.11';
 $strFields = 'Champs';
-$strFieldsEmpty = 'Il faut indiquer le nombre de champs';
 $strFieldsEnclosedBy = 'Champs entours par';
 $strFieldsEscapedBy = 'Caractre spcial';
 $strFieldsTerminatedBy = 'Champs termins par';
@@ -299,6 +295,7 @@ $strFileNameTemplateDescriptionServer = 'nom de serveur';
 $strFileNameTemplateDescriptionTable = 'nom de table';
 $strFileNameTemplate = 'Modle de nom de fichier';
 $strFileNameTemplateRemember = 'se souvenir du modle';
+$strFiles = 'Fichiers';
 $strFileToImport = 'Fichier  importer';
 $strFixed = 'fixe';
 $strFlushPrivilegesNote = 'Note: phpMyAdmin obtient la liste des privilges directement  partir des tables MySQL. Le contenu de ces tables peut tre diffrent des privilges effectifs, si des changements manuels ont t apports. Dans ce cas, vous devriez %srecharger les privilges%s avant de continuer.';
@@ -335,7 +332,7 @@ $strHasBeenCreated = 'a t cr(e).';
 $strHaveToShow = 'Vous devez choisir au moins une colonne  afficher';
 $strHebrew = 'hbreu';
 $strHelp = 'Aide';
-$strHexForBinary = 'Encoder les champs binaires en hexadcimal';
+$strHexForBLOB = 'Utiliser l\'hexadecimal pour les BLOB';
 $strHide         = 'Cacher';
 $strHideShowAll = 'Cacher/montrer tout';
 $strHideShowNoRelation = 'Cacher/montrer les tables sans liens';
@@ -344,9 +341,7 @@ $strHomepageOfficial = 'Site officiel de phpMyAdmin';
 $strHostEmpty = 'Le nom de serveur est vide';
 $strHost = 'Serveur';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Options d\'exportation Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Options d\'exportation Microsoft Word 2000';
 $strHungarian = 'hongrois';
 
 $strIcelandic = 'islandais';
@@ -362,14 +357,12 @@ $strImportFormat = 'Format du fichier d\'importation';
 $strImport = 'Importer';
 $strImportSuccessfullyFinished = 'L\'importation s\'est termine avec succs, %d requtes excutes.';
 $strIndexes = 'Index';
+$strIndexesSeemEqual = 'Les index suivants semblent quivalents, vous devriez en liminer un.';
 $strIndexHasBeenDropped = 'L\'index %s a t effac';
 $strIndex = 'Index';
 $strIndexName = 'Nom de la clef&nbsp;:';
 $strIndexType = 'Type de clef&nbsp;:';
-$strIndexWarningMultiple = 'Plus d\'un index de type %s existe pour la colonne `%s`';
-$strIndexWarningPrimary = 'La colonne `%s` ne devrait pas faire partie  la fois d\'une cl primaire et d\'une cl index';
 $strIndexWarningTable = 'Il y a des problmes avec les index de la table `%s`';
-$strIndexWarningUnique = 'La colonne `%s` ne devrait pas faire partie  la fois d\'une cl unique et d\'une cl index';
 $strInnoDBAutoextendIncrement = 'Auto-croissant: Taille de l\'incrment';
 $strInnoDBAutoextendIncrementDesc = 'La valeur de l\'incrment lors de l\'agrandissement du fichier auto-croissant lorsqu\'il devient plein.';
 $strInnoDBBufferPoolSizeDesc = 'La taille de la mmoire-tampon utilise par InnoDB pour les oprations d\'antmoire sur les donnes et les index.';
@@ -418,7 +411,6 @@ $strKnownExternalBug = 'La fonctionnalit %s est affecte par une anomalie connue,
 $strKorean = 'coren';
 
 $strLandscape = 'Paysage';
-$strLanguageFileNotFound = 'Fichier de langue "%1$s" inexistant.';
 $strLanguage = 'Langue';
 $strLanguageUnknown = 'Langue inconnue: %1$s.';
 $strLatchedPages = 'Pages verrouilles';
@@ -429,11 +421,9 @@ $strLatexContinued = '(suite)';
 $strLatexIncludeCaption = 'Inclure les sous-titres';
 $strLatexLabel = 'Cl de l\'tiquette';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Options LaTeX';
 $strLatexStructure = 'Structure de la table __TABLE__';
 $strLatvian = 'letton';
 $strLDI = 'CSV via LOAD DATA';
-$strLDIImportOptions = 'Options pour l\'importation CSV via LOAD DATA';
 $strLDILocal = 'Utiliser l\'option LOCAL';
 $strLengthSet = 'Taille/Valeurs*';
 $strLimitNumRows = 'Nombre d\'enregistrements par page';
@@ -490,6 +480,7 @@ $strMyISAMSortBufferSize = 'Taille de la mmoire tampon';
 $strMySQLCharset = 'Jeu de caractres pour MySQL';
 $strMysqlClientVersion = 'Version du client MySQL';
 $strMySQLConnectionCollation = 'Interclassement pour la connexion MySQL';
+$strMysqlLibDiffersServerVersion = 'La version de votre bibliothque MySQL (%s) diffre de la version de votre serveur MySQL (%s). Ceci peut occasionner un comportement imprvisible.';
 $strMySQLSaid = 'MySQL a rpondu:';
 $strMySQLShowProcess = 'Afficher les processus';
 $strMySQLShowStatus = 'Afficher l\'tat du serveur';
@@ -535,14 +526,13 @@ $strNumSearchResultsTotal = '<b>Total :</b> <i>%s</i> occurence(s)';
 $strNumTables = 'Tables';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'Options pour tableur "Open Document"';
 $strOpenDocumentSpreadsheet = 'Tableur "Open Document"';
-$strOpenDocumentTextOptions = 'Options pour texte "Open Document"';
 $strOpenDocumentText = 'Texte "Open Document"';
 $strOpenNewWindow = 'Ouvrir une nouvelle fentre phpMyAdmin';
 $strOperations = 'Oprations';
 $strOperator = 'Oprateur';
 $strOptimizeTable = 'Optimiser la table';
+$strOptions = 'Options';
 $strOr = 'Ou';
 $strOverhead = 'Perte';
 $strOverwriteExisting = 'craser les fichiers existants';
@@ -560,7 +550,6 @@ $strPasswordNotSame = 'Les mots de passe doivent tre identiques';
 $strPdfDbSchema = 'Schema de la base "%s" - Page %s';
 $strPdfInvalidTblName = 'La table "%s" n\'existe pas !';
 $strPdfNoTables = 'Pas de table !';
-$strPDFOptions = 'Options PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Gnre un rapport contenant les donnes d\'une seule table)';
 $strPDFReportTitle = 'Titre du rapport';
@@ -628,6 +617,7 @@ $strPrivilegesReloaded = 'Les privilges ont t rechargs.';
 $strProcedures = 'Procdures';
 $strProcesses = 'Processus';
 $strProcesslist = 'Liste des processus';
+$strProfiling = 'Profilage';
 $strProtocolVersion = 'Version du protocole';
 $strPutColNames = 'Afficher les noms de champ en premire ligne';
 
@@ -669,12 +659,15 @@ $strReplaceTable = 'Remplacer les donnes de la table avec le fichier';
 $strReplication = 'Rplication';
 $strReset = 'Rinitialiser les valeurs';
 $strResourceLimits = 'Limites de ressources.';
+$strRestartInsertion = 'Recommencer l\'insertion avec %s lignes';
 $strReType = 'Entrer  nouveau';
 $strRevokeAndDeleteDescr = 'Les utilisateurs auront le privilege "USAGE", jusqu\' ce que les privilges soient rechargs.';
 $strRevokeAndDelete = 'Effacer tous les privilges de ces utilisateurs, puis les effacer.';
 $strRevokeMessage = 'Vous avez rvoqu les privilges pour %s';
 $strRevoke = 'Rvoquer';
 $strRomanian = 'roumain';
+$strRoutineReturnType = 'Type retourn';
+$strRoutines = 'Procdures stockes';
 $strRowLength = 'Longueur enr.';
 $strRows = 'Enregistrements';
 $strRowsFrom = 'enregistrement(s)  partir de l\'enregistrement n';
@@ -726,6 +719,7 @@ $strServerTabVariables = 'Variables';
 $strServerTrafficNotes = '<b>Statistiques sur le trafic</b>: Ce tableau indique le trafic rseau observ sur ce serveur MySQL depuis son dmarrage.';
 $strServerVars = 'Variables et rglages du serveur';
 $strServerVersion = 'Version du serveur';
+$strSessionStartupErrorGeneral = 'Erreur lors du dmarrage de la session, veuillez vrifier les erreurs indiques par PHP ou dans le fichier tmoin du serveur web, et configurer PHP correctement.';
 $strSessionValue = 'Valeur pour la session';
 $strSetEnumVal = 'Les diffrentes valeurs des champs de type enum/set sont  spcifier sous la forme \'a\',\'b\',\'c\'...<br />Pour utiliser un caractre "\\" ou "\'" dans l\'une de ces valeurs, faites-le prcder du caractre d\'chappement "\\" (par exemple \'\\\\xyz\' ou \'a\\\'b\').';
 $strShow = 'Afficher';
@@ -815,7 +809,7 @@ $strShowStatusKey_readsDescr = 'Le nombre de lectures physiques d\'un bloc de cl
 $strShowStatusKey_write_requestsDescr = 'Le nombre de requtes en vue d\'crire un bloc de cl dans la cache.';
 $strShowStatusKey_writesDescr = 'Le nombre d\'critures physiques d\'un bloc de cls vers le disque.';
 $strShowStatusLast_query_costDescr = 'Le cot total de la dernire requte compile, tel que calcul par l\'optimiseur de requtes. Utile pour comparer le cot de diverses stratgies pour une mme requte. La valeur de 0 indique qu\'aucune requte n\'a encore t compile.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Le nombre d\'enregistrements en attente d\'criture (INSERT DELAY).';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Le nombre d\'enregistrements en attente d\'criture (INSERT DELAYED).';
 $strShowStatusOpened_tablesDescr = 'Le nombre tables qui ont t ouvertes. Si trop lev, votre cache de table est probablement trop petite.';
 $strShowStatusOpen_filesDescr = 'Le nombre de fichiers qui sont ouverts.';
 $strShowStatusOpen_streamsDescr = 'Le nombre de flux de donnes qui sont ouverts.';
@@ -870,8 +864,6 @@ $strSpanish = 'espagnol';
 $strSplitWordsWithSpace = 'Sparer les mots par un espace (" ").';
 $strSQLCompatibility = 'Mode de compatibilit SQL';
 $strSQLExportType = 'Type d\'exportation';
-$strSQLImportOptions = 'Options SQL';
-$strSQLOptions = 'options SQL';
 $strSQLParserBugMessage = 'Il semble que vous ayiez trouv une anomalie dans l\'analyseur syntaxique SQL. Veuillez examiner votre requte attentivement, et vrifier que vos apostrophes sont conformes. Il se pourrait aussi que vous ayiez charg un fichier dont le contenu binaire n\'est pas entre apostrophes.  Si vous avez accs  MySQL via son interface de commande en mode ligne, vous pouvez y essayer votre requte. Le message d\'erreur prsent plus bas pourrait vous indiquer la source du problme. En dernier recours, veuillez trouver la plus courte requte possible qui cause le problme, et soumettre un rapport d\'anomalie en incluant la section  couper:';
 $strSQLParserUserError = 'Il semble qu\'il y ait une erreur dans votre requte SQL. Le message ci-bas peut vous aider  en trouver la cause.';
 $strSQLQuery = 'requte SQL';
@@ -893,7 +885,6 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Structure et donnes';
 $strStrucExcelCSV = 'CSV pour MS Excel';
 $strStrucNativeExcel = 'Donnes MS Excel (format natif)';
-$strStrucNativeExcelOptions = 'Options pour Excel natif';
 $strStrucOnly = 'Structure seule';
 $strStructPropose = 'Suggrer des optimisations quant  la structure de la table';
 $strStructureForView = 'Structure de la vue';
@@ -959,6 +950,7 @@ $strTransformation_text_plain__imagelink = 'Affiche une image et un lien, le cha
 $strTransformation_text_plain__link = 'Affiche un lien, le champ contient le nom du fichier; en premire option, un prfixe comme "http://domaine.com/", en seconde option, un titre pour le lien.';
 $strTransformation_text_plain__sql = 'Affiche le texte comme une requte SQL avec embellissement de la syntaxe.';
 $strTransformation_text_plain__substr = 'N\'affiche qu\'une partie du champ. En premire option, la position de dpart (par dfaut, 0). En seconde option, le nombre de caractres  afficher (par dfaut, le reste). En troisime option, des caractres  afficher  la fin du texte (par dfaut: "...").';
+$strTriggers = 'Dclencheurs';
 $strTruncateQueries = 'Afficher les requtes tronques';
 $strTurkish = 'turc';
 $strType = 'Type';
@@ -975,6 +967,13 @@ $strUpdateProfileMessage = 'Le profil a t modifi.';
 $strUpdateQuery = 'Mise--jour de la requte';
 $strUpdComTab = 'La documentation indique comment mettre  jour votre table Column_comments';
 $strUpgrade = 'Vous devriez utiliser %s en version %s ou plus rcente.';
+$strUploadErrorCantWrite = 'Erreur lors de l\'criture du fichier sur disque.';
+$strUploadErrorExtension = 'Tlchargement arrt par l\'extension.';
+$strUploadErrorFormSize = 'La taille du fichier tlcharg dpasse la limite permise par la directive MAX_FILE_SIZE prsente dans le formulaire HTML.';
+$strUploadErrorIniSize = 'La taille du fichier tlcharg dpasse la limite permise par la directive upload_max_filesize de php.ini.';
+$strUploadErrorNoTempDir = 'Rpertoire temporaire manquant.';
+$strUploadErrorPartial = 'Le fichier n\'a t que partiellement tlcharg.';
+$strUploadErrorUnknown = 'Erreur inconnue durant le tlchargement.';
 $strUploadLimit = 'Vous avez probablement tent de tlcharger un fichier trop volumineux. Veuillez vous rfrer  la %sdocumentation%s pour des faons de contourner cette limite.';
 $strUploadsNotAllowed = 'Les tlchargements vers ce serveur ne sont pas permis.';
 $strUsage = 'Espace';
@@ -1004,6 +1003,7 @@ $strViewDumpDatabases = 'Schma et/ou contenu des bases de donnes';
 $strViewDumpDB = 'Schma et donnes de la base ';
 $strViewHasBeenDropped = 'La vue %s a t supprime';
 $strViewMaxExactCount = 'Cette vue comporte plus de %d enregistrements. Veuillez vous rfrer  la %sdocumentation%s.';
+$strViewName = 'Nom de la vue';
 $strView = 'Vue';
 
 $strWebServerUploadDirectoryError = 'Le rpertoire de transfert est inaccessible';
@@ -1016,7 +1016,6 @@ $strWithChecked = 'Pour la slection :';
 $strWriteRequests = 'Requtes d\'criture';
 $strWrongUser = 'Erreur d\'utilisateur/mot de passe. Accs refus';
 
-$strXMLOptions = 'Options XML';
 $strXML = 'XML';
 
 $strYes = 'Oui';
